@@ -19,8 +19,10 @@
 //!
 //! # Crate Features
 //!
-//! Default feature set is wide – it includes all default [`mysql_common` features][myslqcommonfeatures]
-//! as well as `native-tls`-based TLS support.
+//! By default there are only two features enabled:
+//!
+//! *   `flate2/zlib` — choosing flate2 backend is mandatory
+//! *   `derive` — see ["Derive Macros" section in `mysql_common` docs][mysqlcommonderive]
 //!
 //! ## List Of Features
 //!
@@ -36,21 +38,18 @@
 //!     mysql_async = { version = "*", default-features = false, features = ["minimal"]}
 //!     ```
 //!
-//! *   `minimal-rust` - same as `minimal` but rust-based flate2 backend is chosen. Enables:
+//! *   `minimal-rust` - same as `minimal` but with rust-based flate2 backend. Enables:
 //!
 //!     -    `flate2/rust_backend`
 //!
 //! *   `default` – enables the following set of features:
 //!
-//!     -   `minimal`
-//!     -   `native-tls-tls`
-//!     -   `bigdecimal`
-//!     -   `rust_decimal`
-//!     -   `time`
-//!     -   `frunk`
-//!     -   `binlog`
+//!     -   `flate2/zlib`
+//!     -   `derive`
 //!
-//! *   `default-rustls` – same as default but with `rustls-tls` instead of `native-tls-tls`.
+//! *   `default-rustls` – default set of features with TLS via `rustls/aws-lc-rs`
+//!
+//! *   `default-rustls-ring` – default set of features with TLS via `rustls/ring`
 //!
 //!     **Example:**
 //!
@@ -59,21 +58,22 @@
 //!     mysql_async = { version = "*", default-features = false, features = ["default-rustls"] }
 //!     ```
 //!
-//! *   `native-tls-tls` – enables `native-tls`-based TLS support _(conflicts with `rustls-tls`)_
+//! *   `native-tls-tls` – enables TLS via `native-tls`
 //!
 //!     **Example:**
 //!
 //!     ```toml
 //!     [dependencies]
-//!     mysql_async = { version = "*", default-features = false, features = ["native-tls-tls"] }
+//!     mysql_async = { version = "*", default-features = false, features = ["minimal", "native-tls-tls"] }
 //!
-//! *   `rustls-tls` – enables `native-tls`-based TLS support _(conflicts with `native-tls-tls`)_
+//! *   `rustls-tls` - enables rustls TLS backend with no provider. You should enable one
+//!     of existing providers using `aws-lc-rs` or `ring` features:
 //!
 //!     **Example:**
 //!
 //!     ```toml
 //!     [dependencies]
-//!     mysql_async = { version = "*", default-features = false, features = ["rustls-tls"] }
+//!     mysql_async = { version = "*", default-features = false, features = ["minimal-rust", "rustls-tls", "ring"] }
 //!
 //! *   `tracing` – enables instrumentation via `tracing` package.
 //!
@@ -93,7 +93,7 @@
 //!
 //!     -   `mysql_common/binlog"
 //!
-//! ### Proxied features
+//! ### Proxied features (see [`mysql_common`` fatures][myslqcommonfeatures])
 //!
 //! *   `derive` – enables `mysql_common/derive` feature
 //! *   `chrono` = enables `mysql_common/chrono` feature
@@ -103,6 +103,7 @@
 //! *   `frunk` = enables `mysql_common/frunk` feature
 //!
 //! [myslqcommonfeatures]: https://github.com/blackbeam/rust_mysql_common#crate-features
+//! [mysqlcommonderive]: https://github.com/blackbeam/rust_mysql_common?tab=readme-ov-file#derive-macros
 //!
 //! # TLS/SSL Support
 //!
@@ -453,8 +454,11 @@ mod queryable;
 
 type BoxFuture<'a, T> = futures_core::future::BoxFuture<'a, Result<T>>;
 
-static BUFFER_POOL: once_cell::sync::Lazy<Arc<crate::buffer_pool::BufferPool>> =
-    once_cell::sync::Lazy::new(Default::default);
+fn buffer_pool() -> &'static Arc<crate::buffer_pool::BufferPool> {
+    static BUFFER_POOL: std::sync::OnceLock<Arc<crate::buffer_pool::BufferPool>> =
+        std::sync::OnceLock::new();
+    BUFFER_POOL.get_or_init(Default::default)
+}
 
 #[cfg(feature = "binlog")]
 #[doc(inline)]
@@ -546,6 +550,12 @@ pub use self::queryable::{BinaryProtocol, TextProtocol};
 #[doc(inline)]
 pub use self::queryable::stmt::Statement;
 
+#[doc(inline)]
+pub use self::conn::pool::Metrics;
+
+#[doc(inline)]
+pub use crate::connection_like::{Connection, ToConnectionResult};
+
 /// Futures used in this crate
 pub mod futures {
     pub use crate::conn::pool::futures::{DisconnectPool, GetConn};
@@ -553,6 +563,8 @@ pub mod futures {
 
 /// Traits used in this crate
 pub mod prelude {
+    #[doc(inline)]
+    pub use crate::connection_like::ToConnection;
     #[doc(inline)]
     pub use crate::local_infile_handler::GlobalHandler;
     #[doc(inline)]
@@ -562,6 +574,8 @@ pub mod prelude {
     #[doc(inline)]
     pub use crate::queryable::Queryable;
     #[doc(inline)]
+    pub use mysql_common::prelude::ColumnIndex;
+    #[doc(inline)]
     pub use mysql_common::prelude::FromRow;
     #[doc(inline)]
     pub use mysql_common::prelude::{FromValue, ToValue};
@@ -587,17 +601,6 @@ pub mod prelude {
     pub trait StatementLike: crate::queryable::stmt::StatementLike {}
     impl<T: crate::queryable::stmt::StatementLike> StatementLike for T {}
 
-    /// Everything that is a connection.
-    ///
-    /// Note that you could obtain a `'static` connection by giving away `Conn` or `Pool`.
-    pub trait ToConnection<'a, 't: 'a>: crate::connection_like::ToConnection<'a, 't> {}
-    // explicitly implemented because of rusdoc
-    impl<'a> ToConnection<'a, 'static> for &'a crate::Pool {}
-    impl ToConnection<'static, 'static> for crate::Pool {}
-    impl ToConnection<'static, 'static> for crate::Conn {}
-    impl<'a> ToConnection<'a, 'static> for &'a mut crate::Conn {}
-    impl<'a, 't> ToConnection<'a, 't> for &'a mut crate::Transaction<'t> {}
-
     /// Trait for protocol markers [`crate::TextProtocol`] and [`crate::BinaryProtocol`].
     pub trait Protocol: crate::queryable::Protocol {}
     impl Protocol for crate::BinaryProtocol {}
@@ -608,9 +611,8 @@ pub mod prelude {
 
 #[doc(hidden)]
 pub mod test_misc {
-    use lazy_static::lazy_static;
-
     use std::env;
+    use std::sync::OnceLock;
 
     use crate::opts::{Opts, OptsBuilder, SslOpts};
 
@@ -621,26 +623,17 @@ pub mod test_misc {
         _dummy(err);
     }
 
-    lazy_static! {
-        pub static ref DATABASE_URL: String = {
-            if let Ok(url) = env::var("DATABASE_URL") {
-                let opts = Opts::from_url(&url).expect("DATABASE_URL invalid");
-                if opts
-                    .db_name()
-                    .expect("a database name is required")
-                    .is_empty()
-                {
-                    panic!("database name is empty");
-                }
-                url
-            } else {
-                "mysql://root:password@localhost:3307/mysql".into()
-            }
-        };
-    }
-
     pub fn get_opts() -> OptsBuilder {
-        let mut builder = OptsBuilder::from_opts(Opts::from_url(&DATABASE_URL).unwrap());
+        static DATABASE_OPTS: OnceLock<Opts> = OnceLock::new();
+        let database_opts = DATABASE_OPTS.get_or_init(|| {
+            if let Ok(url) = env::var("DATABASE_URL") {
+                Opts::from_url(&url).expect("DATABASE_URL invalid")
+            } else {
+                Opts::from_url("mysql://root:password@localhost:3307/mysql").unwrap()
+            }
+        });
+
+        let mut builder = OptsBuilder::from_opts(database_opts.clone());
         if test_ssl() {
             let ssl_opts = SslOpts::default()
                 .with_danger_skip_domain_validation(true)
